from odoo import models, fields


class Category(models.Model):
    _inherit = "dms.category"

    expiry_date = fields.Boolean(string="Expiry date")
    expiry_self_check = fields.Boolean(string="Expiry self-check")
    auto_send_email = fields.Boolean(string="Auto send email")
    template_email_id = fields.Many2one("mail.template", string="Email template")



{
    'name': "document_validation_dms_field",
    'version': '12.0.0.0.0',
    'depends': ['base', 'crm', 'dms', 'dms_field'],
    'author': "Som IT, Som Connexió",
    'category': 'Document Validation dms field',
    'summary': "",
    'data': [
        'data/dms_category_data.xml',
        'data/dms_storage_data.xml',
        'views/dms_category_views.xml',
        'views/dms_directory_views.xml',
        'views/dms_field_views.xml',
        'views/crm_lead_views.xml',
    ],
}
